qemu-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Qemu-devel] [PATCH 7/8] qtest/ahci: add qcow2 support to ahci-test


From: John Snow
Subject: [Qemu-devel] [PATCH 7/8] qtest/ahci: add qcow2 support to ahci-test
Date: Thu, 19 Feb 2015 17:30:02 -0500

This will enable the testing of high offsets without
wasting a lot of disk space, and does not impact the
previous tests.

Signed-off-by: John Snow <address@hidden>
---
 tests/ahci-test.c     | 15 +++++----------
 tests/libqos/libqos.c | 30 ++++++++++++++++++++++++++++++
 tests/libqos/libqos.h |  1 +
 3 files changed, 36 insertions(+), 10 deletions(-)

diff --git a/tests/libqos/libqos.c b/tests/libqos/libqos.c
index bc8beb2..3577401 100644
--- a/tests/libqos/libqos.c
+++ b/tests/libqos/libqos.c
@@ -61,3 +61,33 @@ void qtest_shutdown(QOSState *qs)
     qtest_quit(qs->qts);
     g_free(qs);
 }
+
+int mkqcow2(const char *file, unsigned size_mb)
+{
+    pid_t pid;
+    int rc;
+    char buff[32];
+
+    snprintf(buff, 32, "%uM", size_mb);
+
+    pid = fork();
+    switch (pid) {
+    case -1:
+        perror("fork failed");
+        return -1;
+    case 0:
+        close(fileno(stdout));
+        rc = open("/dev/null", O_WRONLY);
+        g_assert_cmpint(rc, ==, fileno(stdout));
+        execl("./qemu-img", "qemu-img", "create", "-f", "qcow2",
+              file, buff, NULL);
+        perror("execl failed");
+        exit(-1);
+    default:
+        wait(&rc);
+        g_assert_cmpint(rc, ==, 0);
+        return rc;
+    }
+
+    g_assert_not_reached();
+}
diff --git a/tests/libqos/libqos.h b/tests/libqos/libqos.h
index 612d41e..5abd2bd 100644
--- a/tests/libqos/libqos.h
+++ b/tests/libqos/libqos.h
@@ -19,6 +19,7 @@ typedef struct QOSState {
 QOSState *qtest_vboot(QOSOps *ops, const char *cmdline_fmt, va_list ap);
 QOSState *qtest_boot(QOSOps *ops, const char *cmdline_fmt, ...);
 void qtest_shutdown(QOSState *qs);
+int mkqcow2(const char *file, unsigned size_mb);
 
 static inline uint64_t qmalloc(QOSState *q, size_t bytes)
 {
diff --git a/tests/ahci-test.c b/tests/ahci-test.c
index 0d4a3df..38550c6 100644
--- a/tests/ahci-test.c
+++ b/tests/ahci-test.c
@@ -39,8 +39,8 @@
 #include "hw/pci/pci_ids.h"
 #include "hw/pci/pci_regs.h"
 
-/* Test-specific defines. */
-#define TEST_IMAGE_SIZE    (64 * 1024 * 1024)
+/* Test-specific defines -- in MiB */
+#define TEST_IMAGE_SIZE_MB (200 * 1024)
 
 /*** Globals ***/
 static char tmp_path[] = "/tmp/qtest.XXXXXX";
@@ -81,7 +81,7 @@ static AHCIQState *ahci_boot(void)
     s = g_malloc0(sizeof(AHCIQState));
 
     cli = "-drive if=none,id=drive0,file=%s,cache=writeback,serial=%s"
-        ",format=raw"
+        ",format=qcow2"
         " -M q35 "
         "-device ide-hd,drive=drive0 "
         "-global ide-hd.ver=%s";
@@ -1050,7 +1050,6 @@ static void create_ahci_io_test(enum IOMode type, enum 
AddrMode addr,
 int main(int argc, char **argv)
 {
     const char *arch;
-    int fd;
     int ret;
     int c;
     int i, j, k;
@@ -1087,12 +1086,8 @@ int main(int argc, char **argv)
         return 0;
     }
 
-    /* Create a temporary raw image */
-    fd = mkstemp(tmp_path);
-    g_assert(fd >= 0);
-    ret = ftruncate(fd, TEST_IMAGE_SIZE);
-    g_assert(ret == 0);
-    close(fd);
+    /* Create a temporary qcow2 image */
+    mkqcow2(tmp_path, TEST_IMAGE_SIZE_MB);
 
     /* Run the tests */
     qtest_add_func("/ahci/sanity",     test_sanity);
-- 
1.9.3




reply via email to

[Prev in Thread] Current Thread [Next in Thread]